# TGAM Pattern Library

## Introduction

This project forms the foundation of the Globe and Mail's living style guide. It serves as the single "source of truth" for how our brand is represented across all of our digital products.

The following documentation explains the purpose and intention of this project, provides step-by-step instructions on how to install the application on your local machine, and explains how to publish and deploy the files. Thorough documentation on how to work with the codebase itself (i.e. how to create pages, "specimens", etc.) can be found here: https://globeandmail.github.io/ux-pattern-library/

The living style guide website can be found here: http://documentation.colo.theglobeandmail.com/ux-pattern-library/

## Purpose

The purpose of this project is as follows:

### To distribute and synchronize our UI component code

All of our user interface HTML, CSS and JavaScript is housed in this repository, and we distribute it via NPM. This makes it possible for outside projects (such as the Globe and Mail website) to import the code and make use of it. Importing the code as an external dependency enables us to keep it synchronized across all of the products that consume it. Distributing the code in this way means that developers are unable to edit it directly within their own codebases. Instead, they must collaborate with other teams to craft a single set of UI components that will be shared across all of our digital properties.

### To document and showcase our UI components in action

This project doubles as a static website generator. The website that it generates provides a place for us to document, categorize and showcase our user interface design patterns in action, in the form of "living" HTML components. Designers, developers and other stakeholders can huddle around the website to discuss ideas, play with existing components and test out experimental components before integrating them into their products. Documenting our design system in this manner challenges us to establish a shared vocabulary throughout the organization and fosters interdisciplinary collaboration.

## Getting started

1. If you haven't already done so, download and install [Node.js](https://nodejs.org/) (which includes the [NPM command-line tool](https://www.npmjs.com/)). You'll need Node version 6 or higher.
2. Open your terminal and `git clone` this repository.
3. Navigate to the project directory.
4. Run `npm install`.
5. Run `npm start`.
6. Once the build tasks have finished running, the website should automatically open in your web browser.

## Deploying the static website

In order to deploy the latest files to the web server, you'll need to log in to Bamboo and run the build plan:

1. Log in to [Bamboo](http://bamboo1.colo.theglobeandmail.com/).
2. Select `Build` -> `All build plans` from the menu.
3. Find `ux-pattern-library` in the list.
4. Click the `Run` icon in the left-hand side of the table row.
5. When the build plan has finished, visit: http://documentation.colo.theglobeandmail.com/ux-pattern-library/. You may need to empty your browser's cache in order to see your changes.

## Publishing the NPM package

If you do not already have an NPM account, then you'll need to [sign up for one](https://www.npmjs.com/signup/) (it's free). Once you have an account, your NPM user will need to be granted `owner` permissions to the `tgam-patterns` package. You can check whether or not you've been granted the necessary permissions by running `npm owner list`.

In order to publish a new version of the NPM module, you'll need to update the package version number:

1. Make sure you're on the `master` branch: `git checkout master`.
2. Increment the NPM package's version number via `npm version patch`. This will update the `package.json` file and create a commit that contains the change.
3. Push the newly-created commit via `git push origin master`.
4. Publish the NPM package and push it out to the NPM registry via `npm publish`
5. If `npm publish` is unsuccessful, you probably just need to login to your NPM account first, via `npm login`.

## Importing the NPM package into outside projects

In order to make use of the UI component code that's housed within the pattern library, you'll first need to install the `tgam-patterns` NPM package into your project as a dependency.

1. If you haven't already done so, initialize your project via `npm init`.
2. Install the pattern library NPM package via `npm install --save-dev tgam-patterns`.
3. Install the [node-sass-asset-functions](https://www.npmjs.com/package/node-sass-asset-functions) NPM package via `npm install --save-dev node-sass-asset-functions`. This package is a "peer dependency", which means that it must be installed alongside the `tgam-patterns` package in order for things to work properly. It will allow you to process the `font-url()` and `image-url()` SCSS helpers that some of the `.scss` files in the pattern library utilize.
4. You should now be able to `@import` SCSS files from the `node_modules/tgam-patterns/patterns/stylesheets` directory and `require()` or `import` JavaScript files from the `node_modules/tgam-patterns/patterns/javascripts` directory.
5. You'll need to install and configure the [node-sass](https://www.npmjs.com/package/node-sass) NPM package in order to compile the SCSS files into CSS. Otherwise, if you're using [Gulp](http://gulpjs.com/) or [Grunt](http://gruntjs.com/), then you should install [gulp-sass](https://www.npmjs.com/package/gulp-sass) or [grunt-sass](https://www.npmjs.com/package/grunt-sass).
6. Next, you'll need to configure [node-sass-asset-functions](https://www.npmjs.com/package/node-sass-asset-functions) to work with your SASS compilation setup. See their documentation page for instructions.
7. Finally, you'll need to setup a pipeline to transpile and bundle the JavaScript files. You can use [Webpack](https://webpack.github.io/) or [Browserify](http://browserify.org/) for this. See their documentation websites for details.

### Referencing a Git branch instead of an NPM package version

During development, you may find it useful to import the pattern library files from a Git feature branch instead of from the NPM registry. This enables you to commit and push code to your `ux-pattern-library` branch, then immediately pull it into your outside project, without having to publish a new version to NPM each time. This is ideal because you don't want to publish an official release version to NPM until your code is production-ready.

**Example of pulling in a Git branch** (which you would do during development):

```
"dependencies": { "tgam-patterns": "globeandmail/ux-pattern-library#branch-name" }
```

Once you've finished your work and your code is production-ready, you should then merge your `ux-pattern-library` branch into `master`, publish a new version to NPM, then point the `tgam-patterns` dependency in your consuming project's `package.json` back to the NPM registry once again.

**Example of pulling in a version of the module from NPM** (which you should do in production):

```
"dependencies": { "tgam-patterns": "2.0.0" }
```
