/**
 * js logic specific to scrolling menu with arrow elements
 */

const moveStartSpeed = 2;
const speedMultiplier = 1.1;
const intervalTime = 50;
const arrowLeftSelector = ".c-control--arrow-left";
const arrowRightSelector = ".c-control--arrow-right";
const headerNavListSelector = ".c-header-nav__bar__list";

let arrowLeft;
let arrowRight;
let headerNavList;
let moveSpeed = moveStartSpeed;
let scrollInterval;
let menuScrollObject = {};

/**
 * @method init
 * @description init method, adds event listener for scroll and resize
 * @return void
 */
menuScrollObject.init = () => {
  headerNavList = document.querySelector(headerNavListSelector);
  arrowLeft = document.querySelector(arrowLeftSelector);
  arrowRight = document.querySelector(arrowRightSelector);

  // scrolling menu event handlers
  arrowLeft.addEventListener("mousedown", () => {
    menuScrollObject.cancelInterval();
    scrollInterval = setInterval(menuScrollObject.scrollMenuLeft, intervalTime);
  });

  arrowLeft.addEventListener("mouseup", menuScrollObject.cancelInterval);

  arrowRight.addEventListener("mousedown", () => {
    menuScrollObject.cancelInterval();
    scrollInterval = setInterval(menuScrollObject.scrollMenuRight, intervalTime);
  });

  arrowRight.addEventListener("mouseup", menuScrollObject.cancelInterval);
};

/**
 * @method scrollMenuLeft
 * @description the speed increases the longer you hold the button
 * @return void
 */
menuScrollObject.scrollMenuLeft = () => {
  moveSpeed *= speedMultiplier;
  headerNavList.scrollLeft += moveSpeed;
};

/**
 * @method scrollMenuRight
 * @description the speed increases the longer you hold the button
 * @return void
 */
menuScrollObject.scrollMenuRight = () => {
  moveSpeed *= speedMultiplier;
  headerNavList.scrollLeft -= moveSpeed;
};

/**
 * @method cancelInterval
 * @description cancels interval for scrolling
 * @return void
 */
menuScrollObject.cancelInterval = () => {
  moveSpeed = moveStartSpeed;
  clearInterval(scrollInterval);
};

export default menuScrollObject;
